==> jc-1.4.0.tar.gz: java/security/acl/NotOwnerException.h <==
// public class java.security.acl.NotOwnerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6b969f8d6002dd83 java_security_acl_NotOwnerException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_acl_NotOwnerException_H_
#define _JC_java_security_acl_NotOwnerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_acl_NotOwnerException$sub_refs	_jc_java_security_acl_NotOwnerException$sub_refs;
typedef struct _jc_java_security_acl_NotOwnerException$sub_nonrefs	_jc_java_security_acl_NotOwnerException$sub_nonrefs;
typedef struct _jc_java_security_acl_NotOwnerException$refs	_jc_java_security_acl_NotOwnerException$refs;
typedef struct _jc_java_security_acl_NotOwnerException$nonrefs	_jc_java_security_acl_NotOwnerException$nonrefs;
typedef struct _jc_java_security_acl_NotOwnerException$object	_jc_java_security_acl_NotOwnerException$object;

typedef struct _jc_java_security_acl_NotOwnerException$fields_struct	_jc_java_security_acl_NotOwnerException$fields_struct;
typedef const struct _jc_java_security_acl_NotOwnerException$vmethods	_jc_java_security_acl_NotOwnerException$vmethods;
typedef const struct _jc_java_security_acl_NotOwnerException$vtable	_jc_java_security_acl_NotOwnerException$vtable;
typedef const struct _jc_java_security_acl_NotOwnerException$vtype	_jc_java_security_acl_NotOwnerException$vtype;

// Class fields structure
struct _jc_java_security_acl_NotOwnerException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_acl_NotOwnerException$fields_struct _jc_java_security_acl_NotOwnerException$class_fields;

// Constructors
extern void _jc_java_security_acl_NotOwnerException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_acl_NotOwnerException$object *);

// Virtual methods structure
struct _jc_java_security_acl_NotOwnerException$vmethods {
};

// Vtable
struct _jc_java_security_acl_NotOwnerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_acl_NotOwnerException$vmethods	java_security_acl_NotOwnerException;
};

// Vtype
struct _jc_java_security_acl_NotOwnerException$vtype {
	_jc_type			type;
	_jc_java_security_acl_NotOwnerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_acl_NotOwnerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_acl_NotOwnerException$refs {
    _jc_java_security_acl_NotOwnerException$sub_refs	java_security_acl_NotOwnerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_acl_NotOwnerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_acl_NotOwnerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_acl_NotOwnerException$sub_nonrefs	java_security_acl_NotOwnerException;
};

// Object instance structure
struct _jc_java_security_acl_NotOwnerException$object {
	_jc_java_security_acl_NotOwnerException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_acl_NotOwnerException$vtype	*vtype;
	_jc_java_security_acl_NotOwnerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_acl_NotOwnerException$vtype _jc_java_security_acl_NotOwnerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_acl_NotOwnerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_acl_NotOwnerException$class_object;

#endif	/* _JC_java_security_acl_NotOwnerException_H_ */

==> jc-1.4.6.tar.gz: java/security/acl/NotOwnerException.h <==
// public class java.security.acl.NotOwnerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6b969f8d6002dd83 java_security_acl_NotOwnerException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_acl_NotOwnerException_H_
#define _JC_java_security_acl_NotOwnerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_acl_NotOwnerException$sub_refs	_jc_java_security_acl_NotOwnerException$sub_refs;
typedef struct _jc_java_security_acl_NotOwnerException$sub_nonrefs	_jc_java_security_acl_NotOwnerException$sub_nonrefs;
typedef struct _jc_java_security_acl_NotOwnerException$refs	_jc_java_security_acl_NotOwnerException$refs;
typedef struct _jc_java_security_acl_NotOwnerException$nonrefs	_jc_java_security_acl_NotOwnerException$nonrefs;
typedef struct _jc_java_security_acl_NotOwnerException$object	_jc_java_security_acl_NotOwnerException$object;

typedef struct _jc_java_security_acl_NotOwnerException$fields_struct	_jc_java_security_acl_NotOwnerException$fields_struct;
typedef const struct _jc_java_security_acl_NotOwnerException$vmethods	_jc_java_security_acl_NotOwnerException$vmethods;
typedef const struct _jc_java_security_acl_NotOwnerException$vtable	_jc_java_security_acl_NotOwnerException$vtable;
typedef const struct _jc_java_security_acl_NotOwnerException$vtype	_jc_java_security_acl_NotOwnerException$vtype;

// Class fields structure
struct _jc_java_security_acl_NotOwnerException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_acl_NotOwnerException$fields_struct _jc_java_security_acl_NotOwnerException$class_fields;

// Constructors
extern void _jc_java_security_acl_NotOwnerException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_acl_NotOwnerException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_acl_NotOwnerException$vmethods {
};

// Vtable
struct _jc_java_security_acl_NotOwnerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_acl_NotOwnerException$vmethods	java_security_acl_NotOwnerException;
};

// Vtype
struct _jc_java_security_acl_NotOwnerException$vtype {
	_jc_type			type;
	_jc_java_security_acl_NotOwnerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_acl_NotOwnerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_acl_NotOwnerException$refs {
    _jc_java_security_acl_NotOwnerException$sub_refs	java_security_acl_NotOwnerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_acl_NotOwnerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_acl_NotOwnerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_acl_NotOwnerException$sub_nonrefs	java_security_acl_NotOwnerException;
};

// Object instance structure
struct _jc_java_security_acl_NotOwnerException$object {
	_jc_java_security_acl_NotOwnerException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_acl_NotOwnerException$vtype	*vtype;
	_jc_java_security_acl_NotOwnerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_acl_NotOwnerException$vtype _jc_java_security_acl_NotOwnerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_acl_NotOwnerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_acl_NotOwnerException$class_object;

#endif	/* _JC_java_security_acl_NotOwnerException_H_ */
